- threshold_dependency
A dependency threshold, usually in the interval [0,1], filtering out dependencies below the threshold.
- threshold_l1
A dependency threshold, usually in the interval [0,1], filtering out self-loop dependencies below the threshold.
- threshold_l2
A dependency threshold, usually in the interval [0,1], filtering out length-two loop dependencies below the threshold.
- threshold_frequency
An absolute frequency threshold filtering dependencies which are observed infrequently.
- all_connected
If TRUE the best antecedent and consequent (as determined by the dependency measure) are going to be added regardless of the threshold value.
- endpoints_connected
If TRUE the start/end activity is added as antecedent/consequent when an activity would not be connected according to the threshold value.